@@ -3,17 +3,18 @@
 /*
  * This file is part of the Predis package.
  *
- * (c) Daniele Alessandri <suppakilla@gmail.com>
+ * (c) 2009-2020 Daniele Alessandri
+ * (c) 2021-2023 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
 
 if (PHP_SAPI !== 'cli') {
-    die("Example scripts are meant to be executed locally via CLI.");
+    exit('Example scripts are meant to be executed locally via CLI.');
 }
 
-require __DIR__.'/../autoload.php';
+require __DIR__ . '/../autoload.php';
 
 function redis_version($info)
 {
@@ -26,23 +27,23 @@ function redis_version($info)
     }
 }
 
-$single_server = array(
+$single_server = [
     'host' => '127.0.0.1',
     'port' => 6379,
     'database' => 15,
-);
+];
 
-$multiple_servers = array(
-    array(
-       'host' => '127.0.0.1',
-       'port' => 6379,
-       'database' => 15,
-       'alias' => 'first',
-    ),
-    array(
-       'host' => '127.0.0.1',
-       'port' => 6380,
-       'database' => 15,
-       'alias' => 'second',
-    ),
-);
+$multiple_servers = [
+    [
+        'host' => '127.0.0.1',
+        'port' => 6379,
+        'database' => 15,
+        'alias' => 'first',
+    ],
+    [
+        'host' => '127.0.0.1',
+        'port' => 6380,
+        'database' => 15,
+        'alias' => 'second',
+    ],
+];
