@@ -3,23 +3,24 @@
 /*
  * This file is part of the Predis package.
  *
- * (c) Daniele Alessandri <suppakilla@gmail.com>
+ * (c) 2009-2020 Daniele Alessandri
+ * (c) 2021-2023 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
 
 /**
- * Constraint that accepts arrays with the same elements but different order.
+ * PHPUnit constraint matching arrays with same elements even in different order.
  */
-class ArrayHasSameValuesConstraint extends \PHPUnit_Framework_Constraint
+class ArrayHasSameValuesConstraint extends \PHPUnit\Framework\Constraint\Constraint
 {
     protected $array;
 
     /**
      * @param array $array
      */
-    public function __construct($array)
+    public function __construct(array $array)
     {
         $this->array = $array;
     }
@@ -27,7 +28,7 @@ class ArrayHasSameValuesConstraint extends \PHPUnit_Framework_Constraint
     /**
      * {@inheritdoc}
      */
-    public function matches($other)
+    public function matches($other): bool
     {
         if (count($this->array) !== count($other)) {
             return false;
@@ -43,7 +44,7 @@ class ArrayHasSameValuesConstraint extends \PHPUnit_Framework_Constraint
     /**
      * {@inheritdoc}
      */
-    public function toString()
+    public function toString(): string
     {
         return 'two arrays contain the same elements.';
     }
@@ -51,7 +52,7 @@ class ArrayHasSameValuesConstraint extends \PHPUnit_Framework_Constraint
     /**
      * {@inheritdoc}
      */
-    protected function failureDescription($other)
+    protected function failureDescription($other): string
     {
         return $this->toString();
     }
