@@ -10,6 +10,7 @@
  * file that was distributed with this source code.
  */
 
+use PHPUnit\AssertSameWithPrecisionConstraint;
 use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\OneOfConstraint;
 use PHPUnit\Util\Test as TestUtil;
@@ -131,6 +132,20 @@ abstract class PredisTestCase extends \PHPUnit\Framework\TestCase
         $this->assertThat($actual, new OneOfConstraint($expected), $message);
     }
 
+    /**
+     * Asserts that two values (of the same type) have the same values with given precision.
+     *
+     * @param  mixed  $expected  Expected value
+     * @param  mixed  $actual    Actual value
+     * @param  int    $precision Precision value should be round to
+     * @param  string $message   Optional assertion message
+     * @return void
+     */
+    public function assertSameWithPrecision($expected, $actual, int $precision = 0, string $message = ''): void
+    {
+        $this->assertThat($actual, new AssertSameWithPrecisionConstraint($expected, $precision), $message);
+    }
+
     /**
      * Asserts that a string matches a given regular expression.
      *
@@ -153,6 +168,10 @@ abstract class PredisTestCase extends \PHPUnit\Framework\TestCase
      */
     protected function getDefaultParametersArray(): array
     {
+        if ($this->isClusterTest()) {
+            return $this->prepareClusterEndpoints();
+        }
+
         return [
             'scheme' => 'tcp',
             'host' => constant('REDIS_SERVER_HOST'),
@@ -237,6 +256,15 @@ abstract class PredisTestCase extends \PHPUnit\Framework\TestCase
             getenv('USE_RELAY') ? ['connections' => 'relay'] : []
         );
 
+        if ($this->isClusterTest()) {
+            $options = array_merge(
+                [
+                    'cluster' => 'redis',
+                ],
+                $options
+            );
+        }
+
         $client = new Client($parameters, $options);
         $client->connect();
 
@@ -537,4 +565,36 @@ abstract class PredisTestCase extends \PHPUnit\Framework\TestCase
             $this->markTestSkipped($message);
         }
     }
+
+    /**
+     * Check annotations if it's matches to cluster test scenario.
+     *
+     * @return bool
+     */
+    protected function isClusterTest(): bool
+    {
+        $annotations = TestUtil::parseTestMethodAnnotations(
+            get_class($this),
+            $this->getName(false)
+        );
+
+        return isset($annotations['method']['requiresRedisVersion'], $annotations['method']['group'])
+            && !empty($annotations['method']['requiresRedisVersion'])
+            && in_array('connected', $annotations['method']['group'], true)
+            && in_array('cluster', $annotations['method']['group'], true);
+    }
+
+    /**
+     * Parse comma-separated cluster endpoints and convert them into tcp strings.
+     *
+     * @return array
+     */
+    protected function prepareClusterEndpoints(): array
+    {
+        $endpoints = explode(',', constant('REDIS_CLUSTER_ENDPOINTS'));
+
+        return array_map(static function (string $elem) {
+            return 'tcp://' . $elem;
+        }, $endpoints);
+    }
 }
