@@ -3,7 +3,8 @@
 /*
  * This file is part of the Predis package.
  *
- * (c) Daniele Alessandri <suppakilla@gmail.com>
+ * (c) 2009-2020 Daniele Alessandri
+ * (c) 2021-2023 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -13,19 +14,17 @@ namespace Predis;
 
 use PredisTestCase;
 
-/**
- *
- */
 class ClientExceptionTest extends PredisTestCase
 {
     /**
      * @group disconnected
      */
-    public function testExceptionMessage()
+    public function testExceptionMessage(): void
     {
         $message = 'This is a client exception.';
 
-        $this->setExpectedException('Predis\ClientException', $message);
+        $this->expectException('Predis\ClientException');
+        $this->expectExceptionMessage($message);
 
         throw new ClientException($message);
     }
@@ -33,7 +32,7 @@ class ClientExceptionTest extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testExceptionClass()
+    public function testExceptionClass(): void
     {
         $exception = new ClientException();
 
