@@ -3,7 +3,8 @@
 /*
  * This file is part of the Predis package.
  *
- * (c) Daniele Alessandri <suppakilla@gmail.com>
+ * (c) 2009-2020 Daniele Alessandri
+ * (c) 2021-2023 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -13,17 +14,16 @@ namespace Predis\Cluster\Distributor;
 
 use PredisTestCase;
 
-/**
- *
- */
 class EmptyRingExceptionTest extends PredisTestCase
 {
     /**
      * @group disconnected
-     * @expectedException \Predis\Cluster\Distributor\EmptyRingException
      */
-    public function testExceptionMessage()
+    public function testExceptionMessage(): void
     {
+        $this->expectException('Predis\Cluster\Distributor\EmptyRingException');
+        $this->expectExceptionMessage('Empty Ring');
+
         throw new EmptyRingException('Empty Ring');
     }
 }
