@@ -3,7 +3,8 @@
 /*
  * This file is part of the Predis package.
  *
- * (c) Daniele Alessandri <suppakilla@gmail.com>
+ * (c) 2009-2020 Daniele Alessandri
+ * (c) 2021-2023 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -13,15 +14,12 @@ namespace Predis\Cluster\Hash;
 
 use PredisTestCase;
 
-/**
- *
- */
 class CRC16Test extends PredisTestCase
 {
     /**
      * @group disconnected
      */
-    public function testHashGeneration()
+    public function testHashGeneration(): void
     {
         $crc16 = new CRC16();
 
@@ -40,7 +38,7 @@ class CRC16Test extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testHashGenerationWithIntegerValues()
+    public function testHashGenerationWithIntegerValues(): void
     {
         $crc16 = new CRC16();
 
