@@ -12,6 +12,8 @@
 
 namespace Predis\Connection;
 
+use Predis\Client;
+use Predis\Command\RawCommand;
 use PredisTestCase;
 use ReflectionObject;
 use stdClass;
@@ -538,6 +540,27 @@ class FactoryTest extends PredisTestCase
         $factory->create('test://127.0.0.1');
     }
 
+    /**
+     * @group disconnected
+     * @return void
+     */
+    public function testSetClientNameAndVersionOnConnection(): void
+    {
+        $parameters = ['client_info' => true];
+
+        $factory = new Factory();
+        $connection = $factory->create($parameters);
+        $initCommands = $connection->getInitCommands();
+
+        $this->assertInstanceOf(RawCommand::class, $initCommands[0]);
+        $this->assertSame('CLIENT', $initCommands[0]->getId());
+        $this->assertSame(['SETINFO', 'LIB-NAME', 'predis'], $initCommands[0]->getArguments());
+
+        $this->assertInstanceOf(RawCommand::class, $initCommands[1]);
+        $this->assertSame('CLIENT', $initCommands[1]->getId());
+        $this->assertSame(['SETINFO', 'LIB-VER', Client::VERSION], $initCommands[1]->getArguments());
+    }
+
     // ******************************************************************** //
     // ---- HELPER METHODS ------------------------------------------------ //
     // ******************************************************************** //
