@@ -3,7 +3,8 @@
 /*
  * This file is part of the Predis package.
  *
- * (c) Daniele Alessandri <suppakilla@gmail.com>
+ * (c) 2009-2020 Daniele Alessandri
+ * (c) 2021-2023 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -11,24 +12,45 @@
 
 namespace Predis\Replication;
 
-use Predis\Profile;
+use PHPUnit\Framework\MockObject\MockObject;
+use Predis\Command\CommandInterface;
 use PredisTestCase;
 
-/**
- *
- */
 class ReplicationStrategyTest extends PredisTestCase
 {
     /**
      * @group disconnected
      */
-    public function testReadCommands()
+    public function testLoadBalancing(): void
     {
-        $profile = Profile\Factory::getDevelopment();
+        $commands = $this->getCommandFactory();
+        $strategy = new ReplicationStrategy();
+
+        $command = $commands->create('GET', ['key']);
+
+        $this->assertTrue(
+            $strategy->isReadOperation($command),
+            'GET is expected to be a read operation.'
+        );
+
+        $strategy->disableLoadBalancing();
+
+        $this->assertFalse(
+            $strategy->isReadOperation($command),
+            'GET is expected to be a write operation.'
+        );
+    }
+
+    /**
+     * @group disconnected
+     */
+    public function testReadCommands(): void
+    {
+        $commands = $this->getCommandFactory();
         $strategy = new ReplicationStrategy();
 
         foreach ($this->getExpectedCommands('read') as $commandId) {
-            $command = $profile->createCommand($commandId);
+            $command = $commands->create($commandId);
 
             $this->assertTrue(
                 $strategy->isReadOperation($command),
@@ -40,13 +62,13 @@ class ReplicationStrategyTest extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testWriteRequests()
+    public function testWriteRequests(): void
     {
-        $profile = Profile\Factory::getDevelopment();
+        $commands = $this->getCommandFactory();
         $strategy = new ReplicationStrategy();
 
         foreach ($this->getExpectedCommands('write') as $commandId) {
-            $command = $profile->createCommand($commandId);
+            $command = $commands->create($commandId);
 
             $this->assertFalse(
                 $strategy->isReadOperation($command),
@@ -58,13 +80,13 @@ class ReplicationStrategyTest extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testDisallowedCommands()
+    public function testDisallowedCommands(): void
     {
-        $profile = Profile\Factory::getDevelopment();
+        $commands = $this->getCommandFactory();
         $strategy = new ReplicationStrategy();
 
         foreach ($this->getExpectedCommands('disallowed') as $commandId) {
-            $command = $profile->createCommand($commandId);
+            $command = $commands->create($commandId);
 
             $this->assertTrue(
                 $strategy->isDisallowedOperation($command),
@@ -76,18 +98,18 @@ class ReplicationStrategyTest extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testSortCommand()
+    public function testSortCommand(): void
     {
-        $profile = Profile\Factory::getDevelopment();
+        $commands = $this->getCommandFactory();
         $strategy = new ReplicationStrategy();
 
-        $cmdReturnSort = $profile->createCommand('SORT', array('key:list'));
+        $cmdReturnSort = $commands->create('SORT', ['key:list']);
         $this->assertFalse(
             $strategy->isReadOperation($cmdReturnSort),
             'SORT is expected to be a write operation.'
         );
 
-        $cmdStoreSort = $profile->createCommand('SORT', array('key:list', array('store' => 'key:stored')));
+        $cmdStoreSort = $commands->create('SORT', ['key:list', ['store' => 'key:stored']]);
         $this->assertFalse(
             $strategy->isReadOperation($cmdStoreSort),
             'SORT with STORE is expected to be a write operation.'
@@ -97,42 +119,42 @@ class ReplicationStrategyTest extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testBitFieldCommand()
+    public function testBitFieldCommand(): void
     {
-        $profile = Profile\Factory::getDevelopment();
+        $commands = $this->getCommandFactory();
         $strategy = new ReplicationStrategy();
 
-        $command = $profile->createCommand('BITFIELD', array('key'));
+        $command = $commands->create('BITFIELD', ['key']);
         $this->assertTrue(
             $strategy->isReadOperation($command),
             'BITFIELD with no modifiers is expected to be a read operation.'
         );
 
-        $command = $profile->createCommand('BITFIELD', array('key', 'GET', 'u4', '0'));
+        $command = $commands->create('BITFIELD', ['key', 'GET', 'u4', '0']);
         $this->assertTrue(
             $strategy->isReadOperation($command),
             'BITFIELD with GET only is expected to be a read operation.'
         );
 
-        $command = $profile->createCommand('BITFIELD', array('key', 'SET', 'u4', '0', 1));
+        $command = $commands->create('BITFIELD', ['key', 'SET', 'u4', '0', 1]);
         $this->assertFalse(
             $strategy->isReadOperation($command),
             'BITFIELD with SET is expected to be a write operation.'
         );
 
-        $command = $profile->createCommand('BITFIELD', array('key', 'INCRBY', 'u4', '0', 1));
+        $command = $commands->create('BITFIELD', ['key', 'INCRBY', 'u4', '0', 1]);
         $this->assertFalse(
             $strategy->isReadOperation($command),
             'BITFIELD with INCRBY is expected to be a write operation.'
         );
 
-        $command = $profile->createCommand('BITFIELD', array('key', 'GET', 'u4', '0', 'INCRBY', 'u4', '0', 1));
+        $command = $commands->create('BITFIELD', ['key', 'GET', 'u4', '0', 'INCRBY', 'u4', '0', 1]);
         $this->assertFalse(
             $strategy->isReadOperation($command),
             'BITFIELD with GET and INCRBY is expected to be a write operation.'
         );
 
-        $command = $profile->createCommand('BITFIELD', array('key', 'GET', 'u4', '0', 'SET', 'u4', '0', 1));
+        $command = $commands->create('BITFIELD', ['key', 'GET', 'u4', '0', 'SET', 'u4', '0', 1]);
         $this->assertFalse(
             $strategy->isReadOperation($command),
             'BITFIELD with GET and SET is expected to be a write operation.'
@@ -142,24 +164,24 @@ class ReplicationStrategyTest extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testGeoradiusCommand()
+    public function testGeoradiusCommand(): void
     {
-        $profile = Profile\Factory::getDevelopment();
+        $commands = $this->getCommandFactory();
         $strategy = new ReplicationStrategy();
 
-        $command = $profile->createCommand('GEORADIUS', array('key:geo', 15, 37, 200, 'km'));
+        $command = $commands->create('GEORADIUS', ['key:geo', 15, 37, 200, 'km']);
         $this->assertTrue(
             $strategy->isReadOperation($command),
             'GEORADIUS is expected to be a read operation.'
         );
 
-        $command = $profile->createCommand('GEORADIUS', array('key:geo', 15, 37, 200, 'km', 'store', 'key:store'));
+        $command = $commands->create('GEORADIUS', ['key:geo', 15, 37, 200, 'km', 'store', 'key:store']);
         $this->assertFalse(
             $strategy->isReadOperation($command),
             'GEORADIUS with STORE is expected to be a write operation.'
         );
 
-        $command = $profile->createCommand('GEORADIUS', array('key:geo', 15, 37, 200, 'km', 'storedist', 'key:storedist'));
+        $command = $commands->create('GEORADIUS', ['key:geo', 15, 37, 200, 'km', 'storedist', 'key:storedist']);
         $this->assertFalse(
             $strategy->isReadOperation($command),
             'GEORADIUS with STOREDIST is expected to be a write operation.'
@@ -169,24 +191,24 @@ class ReplicationStrategyTest extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testGeoradiusByMemberCommand()
+    public function testGeoradiusByMemberCommand(): void
     {
-        $profile = Profile\Factory::getDevelopment();
+        $commands = $this->getCommandFactory();
         $strategy = new ReplicationStrategy();
 
-        $command = $profile->createCommand('GEORADIUSBYMEMBER', array('key:geo', 15, 37, 200, 'km'));
+        $command = $commands->create('GEORADIUSBYMEMBER', ['key:geo', 15, 37, 200, 'km']);
         $this->assertTrue(
             $strategy->isReadOperation($command),
             'GEORADIUSBYMEMBER is expected to be a read operation.'
         );
 
-        $command = $profile->createCommand('GEORADIUSBYMEMBER', array('key:geo', 15, 37, 200, 'km', 'store', 'key:store'));
+        $command = $commands->create('GEORADIUSBYMEMBER', ['key:geo', 15, 37, 200, 'km', 'store', 'key:store']);
         $this->assertFalse(
             $strategy->isReadOperation($command),
             'GEORADIUSBYMEMBER with STORE is expected to be a write operation.'
         );
 
-        $command = $profile->createCommand('GEORADIUSBYMEMBER', array('key:geo', 15, 37, 200, 'km', 'storedist', 'key:storedist'));
+        $command = $commands->create('GEORADIUSBYMEMBER', ['key:geo', 15, 37, 200, 'km', 'storedist', 'key:storedist']);
         $this->assertFalse(
             $strategy->isReadOperation($command),
             'GEORADIUSBYMEMBER with STOREDIST is expected to be a write operation.'
@@ -195,29 +217,32 @@ class ReplicationStrategyTest extends PredisTestCase
 
     /**
      * @group disconnected
-     * @expectedException \Predis\NotSupportedException
-     * @expectedExceptionMessage The command 'INFO' is not allowed in replication mode.
      */
-    public function testUsingDisallowedCommandThrowsException()
+    public function testUsingDisallowedCommandThrowsException(): void
     {
-        $profile = Profile\Factory::getDevelopment();
+        $this->expectException('Predis\NotSupportedException');
+        $this->expectExceptionMessage("The command 'INFO' is not allowed in replication mode");
+
+        $commands = $this->getCommandFactory();
         $strategy = new ReplicationStrategy();
 
-        $command = $profile->createCommand('INFO');
+        $command = $commands->create('INFO');
         $strategy->isReadOperation($command);
     }
 
     /**
      * @group disconnected
      */
-    public function testDefaultIsWriteOperation()
+    public function testDefaultIsWriteOperation(): void
     {
         $strategy = new ReplicationStrategy();
 
-        $command = $this->getMock('Predis\Command\CommandInterface');
-        $command->expects($this->any())
-                ->method('getId')
-                ->will($this->returnValue('CMDTEST'));
+        /** @var CommandInterface|MockObject */
+        $command = $this->getMockBuilder('Predis\Command\CommandInterface')->getMock();
+        $command
+            ->expects($this->any())
+            ->method('getId')
+            ->willReturn('CMDTEST');
 
         $this->assertFalse($strategy->isReadOperation($command));
     }
@@ -225,14 +250,16 @@ class ReplicationStrategyTest extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testCanSetCommandAsReadOperation()
+    public function testCanSetCommandAsReadOperation(): void
     {
         $strategy = new ReplicationStrategy();
 
-        $command = $this->getMock('Predis\Command\CommandInterface');
-        $command->expects($this->any())
-                ->method('getId')
-                ->will($this->returnValue('CMDTEST'));
+        /** @var CommandInterface|MockObject */
+        $command = $this->getMockBuilder('Predis\Command\CommandInterface')->getMock();
+        $command
+            ->expects($this->any())
+            ->method('getId')
+            ->willReturn('CMDTEST');
 
         $strategy->setCommandReadOnly('CMDTEST', true);
         $this->assertTrue($strategy->isReadOperation($command));
@@ -241,14 +268,16 @@ class ReplicationStrategyTest extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testCanSetCommandAsWriteOperation()
+    public function testCanSetCommandAsWriteOperation(): void
     {
         $strategy = new ReplicationStrategy();
 
-        $command = $this->getMock('Predis\Command\CommandInterface');
-        $command->expects($this->any())
-                ->method('getId')
-                ->will($this->returnValue('CMDTEST'));
+        /** @var CommandInterface|MockObject */
+        $command = $this->getMockBuilder('Predis\Command\CommandInterface')->getMock();
+        $command
+            ->expects($this->any())
+            ->method('getId')
+            ->willReturn('CMDTEST');
 
         $strategy->setCommandReadOnly('CMDTEST', false);
         $this->assertFalse($strategy->isReadOperation($command));
@@ -260,42 +289,42 @@ class ReplicationStrategyTest extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testCanUseCallableToCheckCommand()
+    public function testCanUseCallableToCheckCommand(): void
     {
+        $commands = $this->getCommandFactory();
         $strategy = new ReplicationStrategy();
-        $profile = Profile\Factory::getDevelopment();
 
-        $strategy->setCommandReadOnly('SET', function ($command) {
+        $strategy->setCommandReadOnly('SET', function (CommandInterface $command) {
             return $command->getArgument(1) === true;
         });
 
-        $command = $profile->createCommand('SET', array('trigger', false));
+        $command = $commands->create('SET', ['trigger', false]);
         $this->assertFalse($strategy->isReadOperation($command));
 
-        $command = $profile->createCommand('SET', array('trigger', true));
+        $command = $commands->create('SET', ['trigger', true]);
         $this->assertTrue($strategy->isReadOperation($command));
     }
 
     /**
      * @group disconnected
      */
-    public function testSetLuaScriptAsReadOperation()
+    public function testSetLuaScriptAsReadOperation(): void
     {
+        $commands = $this->getCommandFactory();
         $strategy = new ReplicationStrategy();
-        $profile = Profile\Factory::getDevelopment();
 
         $writeScript = 'redis.call("set", "foo", "bar")';
         $readScript = 'return true';
 
         $strategy->setScriptReadOnly($readScript, true);
 
-        $cmdEval = $profile->createCommand('EVAL', array($writeScript));
-        $cmdEvalSHA = $profile->createCommand('EVALSHA', array(sha1($writeScript)));
+        $cmdEval = $commands->create('EVAL', [$writeScript]);
+        $cmdEvalSHA = $commands->create('EVALSHA', [sha1($writeScript)]);
         $this->assertFalse($strategy->isReadOperation($cmdEval));
         $this->assertFalse($strategy->isReadOperation($cmdEvalSHA));
 
-        $cmdEval = $profile->createCommand('EVAL', array($readScript));
-        $cmdEvalSHA = $profile->createCommand('EVALSHA', array(sha1($readScript)));
+        $cmdEval = $commands->create('EVAL', [$readScript]);
+        $cmdEvalSHA = $commands->create('EVALSHA', [sha1($readScript)]);
         $this->assertTrue($strategy->isReadOperation($cmdEval));
         $this->assertTrue($strategy->isReadOperation($cmdEvalSHA));
     }
@@ -303,39 +332,47 @@ class ReplicationStrategyTest extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testSetLuaScriptAsReadOperationWorksWithScriptCommand()
+    public function testSetLuaScriptAsReadOperationWorksWithScriptCommand(): void
     {
         $strategy = new ReplicationStrategy();
 
-        $command = $this->getMock('Predis\Command\ScriptCommand', array('getScript'));
-        $command->expects($this->any())
-                ->method('getScript')
-                ->will($this->returnValue($script = 'return true'));
+        /** @var CommandInterface|MockObject */
+        $command = $this->getMockBuilder('Predis\Command\ScriptCommand')
+            ->onlyMethods(['getScript'])
+            ->getMock();
+        $command
+            ->expects($this->any())
+            ->method('getScript')
+            ->willReturn($script = 'return true');
 
-        $strategy->setScriptReadOnly($script, function ($command) {
+        $strategy->setScriptReadOnly($script, function (CommandInterface $command) {
             return $command->getArgument(2) === true;
         });
 
-        $command->setArguments(array(false));
+        $command->setArguments([false]);
         $this->assertFalse($strategy->isReadOperation($command));
 
-        $command->setArguments(array(true));
+        $command->setArguments([true]);
         $this->assertTrue($strategy->isReadOperation($command));
     }
 
     /**
      * @group disconnected
      */
-    public function testSetLuaScriptAsReadOperationWorksWithScriptCommandAndCallableCheck()
+    public function testSetLuaScriptAsReadOperationWorksWithScriptCommandAndCallableCheck(): void
     {
         $strategy = new ReplicationStrategy();
 
-        $command = $this->getMock('Predis\Command\ScriptCommand', array('getScript'));
-        $command->expects($this->any())
-                ->method('getScript')
-                ->will($this->returnValue($script = 'return true'));
+        /** @var CommandInterface|MockObject */
+        $command = $this->getMockBuilder('Predis\Command\ScriptCommand')
+            ->onlyMethods(['getScript'])
+            ->getMock(['getScript']);
+        $command
+            ->expects($this->any())
+            ->method('getScript')
+            ->willReturn($script = 'return true');
 
-        $command->setArguments(array('trigger', false));
+        $command->setArguments(['trigger', false]);
 
         $strategy->setScriptReadOnly($script, true);
 
@@ -349,13 +386,13 @@ class ReplicationStrategyTest extends PredisTestCase
     /**
      * Returns the list of expected supported commands.
      *
-     * @param string $type Optional type of command (based on its keys)
+     * @param ?string $type Optional type of command (based on its keys)
      *
      * @return array
      */
-    protected function getExpectedCommands($type = null)
+    protected function getExpectedCommands(string $type = null): array
     {
-        $commands = array(
+        $commands = [
             /* commands operating on the connection */
             'AUTH' => 'read',
             'SELECT' => 'read',
@@ -500,10 +537,10 @@ class ReplicationStrategyTest extends PredisTestCase
             'GEODIST' => 'read',
             'GEORADIUS' => 'variable',
             'GEORADIUSBYMEMBER' => 'variable',
-        );
+        ];
 
         if (isset($type)) {
-            $commands = array_filter($commands, function ($expectedType) use ($type) {
+            $commands = array_filter($commands, function (string $expectedType) use ($type) {
                 return $expectedType === $type;
             });
         }
