@@ -3,7 +3,8 @@
 /*
  * This file is part of the Predis package.
  *
- * (c) Daniele Alessandri <suppakilla@gmail.com>
+ * (c) 2009-2020 Daniele Alessandri
+ * (c) 2021-2023 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -13,17 +14,14 @@ namespace Predis\Response;
 
 use PredisTestCase;
 
-/**
- *
- */
 class ErrorTest extends PredisTestCase
 {
-    const ERR_WRONG_KEY_TYPE = 'ERR Operation against a key holding the wrong kind of value';
+    public const ERR_WRONG_KEY_TYPE = 'ERR Operation against a key holding the wrong kind of value';
 
     /**
      * @group disconnected
      */
-    public function testResponseErrorClass()
+    public function testResponseErrorClass(): void
     {
         $error = new Error(self::ERR_WRONG_KEY_TYPE);
 
@@ -34,7 +32,7 @@ class ErrorTest extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testErrorMessage()
+    public function testErrorMessage(): void
     {
         $error = new Error(self::ERR_WRONG_KEY_TYPE);
 
@@ -44,7 +42,7 @@ class ErrorTest extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testErrorType()
+    public function testErrorType(): void
     {
         $exception = new Error(self::ERR_WRONG_KEY_TYPE);
 
@@ -54,7 +52,7 @@ class ErrorTest extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testToString()
+    public function testToString(): void
     {
         $error = new Error(self::ERR_WRONG_KEY_TYPE);
 
