@@ -3,7 +3,8 @@
 /*
  * This file is part of the Predis package.
  *
- * (c) Daniele Alessandri <suppakilla@gmail.com>
+ * (c) 2009-2020 Daniele Alessandri
+ * (c) 2021-2023 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -12,7 +13,9 @@
 namespace Predis\Response\Iterator;
 
 use Predis\Client;
+use Predis\ClientInterface;
 use Predis\Connection\CompositeStreamConnection;
+use Predis\Connection\NodeConnectionInterface;
 use Predis\Protocol\Text\ProtocolProcessor as TextProtocolProcessor;
 use PredisTestCase;
 
@@ -23,12 +26,15 @@ class MultiBulkTupleTest extends PredisTestCase
 {
     /**
      * @group disconnected
-     * @expectedException \InvalidArgumentException
-     * @expectedExceptionMessage Cannot initialize a tuple iterator using an already initiated iterator.
      */
-    public function testInitiatedMultiBulkIteratorsAreNotValid()
+    public function testInitiatedMultiBulkIteratorsAreNotValid(): void
     {
-        $connection = $this->getMock('Predis\Connection\NodeConnectionInterface');
+        $this->expectException('InvalidArgumentException');
+        $this->expectExceptionMessage('Cannot initialize a tuple iterator using an already initiated iterator');
+
+        /** @var NodeConnectionInterface */
+        $connection = $this->getMockBuilder('Predis\Connection\NodeConnectionInterface')->getMock();
+
         $iterator = new MultiBulk($connection, 2);
         $iterator->next();
 
@@ -37,12 +43,15 @@ class MultiBulkTupleTest extends PredisTestCase
 
     /**
      * @group disconnected
-     * @expectedException \UnexpectedValueException
-     * @expectedExceptionMessage Invalid response size for a tuple iterator.
      */
-    public function testMultiBulkWithOddSizesAreInvalid()
+    public function testMultiBulkWithOddSizesAreInvalid(): void
     {
-        $connection = $this->getMock('Predis\Connection\NodeConnectionInterface');
+        $this->expectException('UnexpectedValueException');
+        $this->expectExceptionMessage('Invalid response size for a tuple iterator');
+
+        /** @var NodeConnectionInterface */
+        $connection = $this->getMockBuilder('Predis\Connection\NodeConnectionInterface')->getMock();
+
         $iterator = new MultiBulk($connection, 3);
 
         new MultiBulkTuple($iterator);
@@ -51,12 +60,14 @@ class MultiBulkTupleTest extends PredisTestCase
     /**
      * @group connected
      */
-    public function testIterableMultibulk()
+    public function testIterableMultibulk(): void
     {
         $client = $this->getClient();
         $client->zadd('metavars', 1, 'foo', 2, 'hoge', 3, 'lol');
 
-        $iterator = new MultiBulkTuple($client->zrange('metavars', '0', '-1', 'withscores'));
+        /** @var MultiBulkIterator */
+        $multibulk = $client->zrange('metavars', '0', '-1', 'withscores');
+        $iterator = new MultiBulkTuple($multibulk);
 
         $this->assertInstanceOf('OuterIterator', $iterator);
         $this->assertInstanceOf('Predis\Response\Iterator\MultiBulkTuple', $iterator);
@@ -64,15 +75,15 @@ class MultiBulkTupleTest extends PredisTestCase
         $this->assertTrue($iterator->valid());
         $this->assertSame(3, $iterator->count());
 
-        $this->assertSame(array('foo', '1'), $iterator->current());
+        $this->assertSame(['foo', '1'], $iterator->current());
         $iterator->next();
         $this->assertTrue($iterator->valid());
 
-        $this->assertSame(array('hoge', '2'), $iterator->current());
+        $this->assertSame(['hoge', '2'], $iterator->current());
         $iterator->next();
         $this->assertTrue($iterator->valid());
 
-        $this->assertSame(array('lol', '3'), $iterator->current());
+        $this->assertSame(['lol', '3'], $iterator->current());
         $iterator->next();
         $this->assertFalse($iterator->valid());
 
@@ -82,12 +93,14 @@ class MultiBulkTupleTest extends PredisTestCase
     /**
      * @group connected
      */
-    public function testGarbageCollectorDropsUnderlyingConnection()
+    public function testGarbageCollectorDropsUnderlyingConnection(): void
     {
         $client = $this->getClient();
         $client->zadd('metavars', 1, 'foo', 2, 'hoge', 3, 'lol');
 
-        $iterator = new MultiBulkTuple($client->zrange('metavars', '0', '-1', 'withscores'));
+        /** @var MultiBulkIterator */
+        $multibulk = $client->zrange('metavars', '0', '-1', 'withscores');
+        $iterator = new MultiBulkTuple($multibulk);
 
         unset($iterator);
 
@@ -102,11 +115,11 @@ class MultiBulkTupleTest extends PredisTestCase
     /**
      * Returns a new client instance.
      *
-     * @return Client
+     * @return ClientInterface
      */
-    protected function getClient()
+    protected function getClient(): ClientInterface
     {
-        $parameters = $this->getParameters(array('read_write_timeout' => 2));
+        $parameters = $this->getParameters(['read_write_timeout' => 2]);
 
         $protocol = new TextProtocolProcessor();
         $protocol->useIterableMultibulk(true);
