@@ -3,7 +3,8 @@
 /*
  * This file is part of the Predis package.
  *
- * (c) Daniele Alessandri <suppakilla@gmail.com>
+ * (c) 2009-2020 Daniele Alessandri
+ * (c) 2021-2023 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -14,15 +15,12 @@ namespace Predis\Transaction;
 use Predis\Client;
 use PredisTestCase;
 
-/**
- *
- */
 class AbortedMultiExecExceptionTest extends PredisTestCase
 {
     /**
      * @group disconnected
      */
-    public function testExceptionClass()
+    public function testExceptionClass(): void
     {
         $client = new Client();
         $transaction = new MultiExec($client);
